@@ -1,7 +1,7 @@
 #' Restrict volume to RoI
 #' @description The \code{nesting.roi} function restricts a "volume" class 
 #' object to the rectangular parallelepiped circumscribed to the chosen RoI.
-#' @param vol "volume" class object
+#' @param obj object of class volume or mesh.
 #' @param struct "struct" class object.
 #' @param roi.name Vector of exact names of the RoI in the \code{struct} object.
 #' By default \code{roi.name = NULL}. See Details.
@@ -19,10 +19,12 @@
 #' @param T.MAT "t.mat" class object, created by 
 #' \link[espadon]{load.patient.from.dicom}, \link[espadon]{load.patient.from.Rdcm} 
 #' or \link[espadon]{load.T.MAT}. If \code{T.MAT = NULL}, \code{struct$ref.pseudo}
-#' must be equal to \code{vol$ref.pseudo}.
+#' must be equal to \code{obj$ref.pseudo}.
 #' @param alias Character string, \code{$alias} of the created object.
 #' @param description Character string, describing the the created object. 
-#' If \code{description = NULL}, it will be that of the \code{vol}.
+#' If \code{description = NULL}, it will be that of the \code{obj}, plus 
+#' "restricted to" the selected RoI.
+#' @param ... Additional arguments \code{vol} (depracated), replaced by \code{obj}.
 #' @return Returns a "volume" class object, in which 3D volume is limited to the
 #' rectangular parallelepiped circumscribed to the chosen RoI, increased by the
 #' requested margins.
@@ -55,10 +57,16 @@
 
 #' @export
 #' @importFrom methods is
-nesting.roi <- function (vol, struct, roi.name = NULL, roi.sname = NULL, 
+nesting.roi <- function (obj, struct, roi.name = NULL, roi.sname = NULL, 
                          roi.idx = NULL, xyz.margin = c (0, 0, 0),
                          vol.restrict = FALSE, 
-                         T.MAT = NULL, alias = "", description = NULL) {
+                         T.MAT = NULL, alias = "", description = NULL,...) {
+  passed <- names(as.list(match.call())[-1])
+  args <- list(...)
+  if (!("obj" %in% passed)){
+    if (is.null(args[['vol']])) stop('argument "obj" is missing, with no default')
+    obj <- args[['vol']]
+  }
   
   roi.idx <- select.names (struct$roi.info$roi.pseudo, roi.name, roi.sname, roi.idx)
   # if (length (roi.idx) != 1) {
@@ -66,8 +74,8 @@ nesting.roi <- function (vol, struct, roi.name = NULL, roi.sname = NULL,
   #   return (NULL)
   # }
   
-  if (!is (vol, "volume")) {
-    warning ("vol should be a volume class object.")
+  if (!(is (obj, "volume") | is (obj, "mesh"))) {
+    warning ("obj must be an object of class volume or mesh.")
     return (NULL)
   }
   
@@ -75,12 +83,7 @@ nesting.roi <- function (vol, struct, roi.name = NULL, roi.sname = NULL,
     warning ("struct should be a struct class object.")
     return (NULL)
   }
-  
-  
-  if(is.null(vol$vol3D.data)){
-    warning ("empty vol3D.data.")
-    return (NULL)
-  }
+
   if(is.null(struct$roi.data)){
     warning ("empty roi.data.")
     return (NULL)
@@ -92,38 +95,62 @@ nesting.roi <- function (vol, struct, roi.name = NULL, roi.sname = NULL,
   
   
   if (all (sapply (roi.idx,function(i) {length(struct$roi.data[[i]])==0}))) return (NULL)
+  if (is.null(description)) description<- paste (obj$description,"restricted to", 
+                                                 paste (struct$roi.info$roi.pseudo[roi.idx], collapse="|"))
   
-  if (!is.null(vol$local.gridx)) {
-    vol$local.gridx <- NULL
-    vol$local.gridy <- NULL
-  }
-  
-  t.mat <- ref.cutplane.add(vol, T.MAT=T.MAT)
-  S_ <- struct.in.new.ref(struct,new.ref.pseudo=paste0(vol$ref.pseudo,"m"), t.mat)
-  vol_ <- vol.in.new.ref(vol, new.ref.pseudo=paste0(vol$ref.pseudo,"m"), t.mat)
+  if(is (obj, "volume")){
+    if(is.null(obj$vol3D.data)){
+      warning ("empty vol3D.data.")
+      return (NULL)
+    }
+    
+    if (!is.null(obj$local.gridx)) {
+      obj$local.gridx <- NULL
+      obj$local.gridy <- NULL
+    }
+    
+    t.mat <- ref.cutplane.add(obj, T.MAT=T.MAT)
+    S_ <- struct.in.new.ref(struct,new.ref.pseudo=paste0(obj$ref.pseudo,"m"), t.mat)
+    vol_ <- vol.in.new.ref(obj, new.ref.pseudo=paste0(obj$ref.pseudo,"m"), t.mat)
+    
+    if (is.null (S_) | is.null (vol_)){
+      warning ("different ref.pseudo.")
+      return (NULL)
+    }
+    pt.min <- c (min (S_$roi.info$min.x[roi.idx]) - xyz.margin[1],
+                 min (S_$roi.info$min.y[roi.idx]) - xyz.margin[2],
+                 min (S_$roi.info$min.z[roi.idx]) - xyz.margin[3])
+    pt.max <- c (max (S_$roi.info$max.x[roi.idx]) + xyz.margin[1],
+                 max (S_$roi.info$max.y[roi.idx]) + xyz.margin[2],
+                 max (S_$roi.info$max.z[roi.idx]) + xyz.margin[3])
+    
+    if (vol.restrict){
+      vol.pt <- vol_$xyz.from.ijk %*% vol_$cube.idx[ , c (1,7)]
+      pt.min <- c (max(pt.min[1], min(vol.pt [1,])), max(pt.min[2], min(vol.pt [2,])), max(pt.min[3], min(vol.pt [3,])))
+      pt.max <- c (min(pt.max[1], max(vol.pt [1,])), min(pt.max[2], max(vol.pt [2,])), min(pt.max[3], max(vol.pt [3,])))
+    }
 
-  if (is.null (S_) | is.null (vol_)){
-    warning ("different ref.pseudo.")
-    return (NULL)
-  }
-  pt.min <- c (min (S_$roi.info$min.x[roi.idx]) - xyz.margin[1],
-               min (S_$roi.info$min.y[roi.idx]) - xyz.margin[2],
-               min (S_$roi.info$min.z[roi.idx]) - xyz.margin[3])
-  pt.max <- c (max (S_$roi.info$max.x[roi.idx]) + xyz.margin[1],
-               max (S_$roi.info$max.y[roi.idx]) + xyz.margin[2],
-               max (S_$roi.info$max.z[roi.idx]) + xyz.margin[3])
-  
-  if (vol.restrict){
-    vol.pt <- vol_$xyz.from.ijk %*% vol_$cube.idx[ , c (1,7)]
-    pt.min <- c (max(pt.min[1], min(vol.pt [1,])), max(pt.min[2], min(vol.pt [2,])), max(pt.min[3], min(vol.pt [3,])))
-    pt.max <- c (min(pt.max[1], max(vol.pt [1,])), min(pt.max[2], max(vol.pt [2,])), min(pt.max[3], max(vol.pt [3,])))
-  }
-  
-
-  if (is.null(description)) description<- paste (vol$description,"restricted to", paste (struct$roi.info$roi.pseudo[roi.idx], collapse="|"))
-  if (pt.min[1]<=pt.max[1] & pt.min[2]<=pt.max[2] & pt.min[3]<=pt.max[3]){
-    vol_ <- nesting.cube(vol=vol_, pt.min=pt.min, pt.max=pt.max, alias = alias, description=description )
-    return(vol.in.new.ref(vol_,new.ref.pseudo=vol$ref.pseudo, t.mat,alias = alias, description=description))
+    if (pt.min[1]<=pt.max[1] & pt.min[2]<=pt.max[2] & pt.min[3]<=pt.max[3]){
+      vol_ <- nesting.cube(obj=vol_, pt.min=pt.min, pt.max=pt.max, alias = alias, description=description )
+      vol <- vol.in.new.ref(vol_,new.ref.pseudo=obj$ref.pseudo, t.mat,alias = alias, description=description)
+      
+      if (alias == "") return(vol)
+      return(.set.ref.obj(vol,list(obj,struct),add=FALSE))
+    }
+    
+  } else {#mesh
+    
+    ext <- get.extreme.pt (struct,roi.idx = roi.idx, ref.pseudo = obj$ref.pseudo, 
+                           T.MAT = T.MAT)
+    if (is.null(ext))  return (NULL)
+    pt.min <- as.numeric(ext[,1]) - xyz.margin 
+    pt.max <- as.numeric(ext[,2]) + xyz.margin
+    
+    if (pt.min[1]<=pt.max[1] & pt.min[2]<=pt.max[2] & pt.min[3]<=pt.max[3]){
+      new.obj <- nesting.cube(obj=obj, pt.min=pt.min, pt.max=pt.max, alias = alias, description=description)
+      if (alias =="") return(new.obj)
+      return(.set.ref.obj(new.obj, list(struct)))
+    }
   }
   return (NULL)
 }
\ No newline at end of file
